troopdata_rebuild_us_states returns a data frame
containing information on U.S. military personnel stationed in each of
the 50 U.S. states (and U.S. territories where reported). Returned by
get_troopdata() when the state_data argument is set to
TRUE.
Format
A data frame with state-year (and state-year-quarter) observations including the following variables:
fipscodeA numeric vector of U.S. Federal Information Processing Standards (FIPS) state codes. Used as the numeric identifier when subsetting via
get_troopdata(host = <numeric>, state_data = TRUE).stateA character vector of U.S. state names. Matched with a case-insensitive
greplfuzzy match when subsetting viaget_troopdata(host = <character>, state_data = TRUE).yearThe year of the observation.
monthThe month of the observation.
quarterThe quarter of the observation.
troops_adThe total number of active duty US military personnel stationed in the state.
army_adTotal number of active duty Army personnel stationed in the state.
navy_adTotal number of active duty Navy personnel stationed in the state.
air_force_adTotal number of active duty Air Force personnel stationed in the state.
marine_corps_adTotal number of active duty Marine Corps personnel stationed in the state.
coast_guard_adTotal number of active duty Coast Guard personnel stationed in the state.
space_force_adTotal number of active duty Space Force personnel stationed in the state.
army_national_guardTotal number of Army National Guard personnel stationed in the state.
air_national_guardTotal number of Air National Guard personnel stationed in the state.
army_reserveTotal number of Army Reserve personnel stationed in the state.
navy_reserveTotal number of Navy Reserve personnel stationed in the state.
marine_corps_reserveTotal number of Marine Corps Reserve personnel stationed in the state.
air_force_reserveTotal number of Air Force Reserve personnel stationed in the state.
coast_guard_reserveTotal number of Coast Guard Reserve personnel stationed in the state.
total_selected_reserveTotal number of reserve US military personnel stationed in the state.
army_civilianTotal number of Army civilian personnel stationed in the state.
navy_civilianTotal number of Navy civilian personnel stationed in the state.
air_force_civilianTotal number of Air Force civilian personnel stationed in the state.
marine_corps_civilianTotal number of Marine Corps civilian personnel stationed in the state.
dod_civilianTotal number of Department of Defense civilian personnel stationed in the state.
total_civilianTotal number of civilian personnel stationed in the state.